@@ -2,6 +2,10 @@
     %W% %G%
 */
 
+#ifdef HAVE_CONFIG_H
+#include "io_lib_config.h"
+#endif
+
 #include <stdlib.h>
 #include <string.h>
 
