@@ -57,6 +57,9 @@
  *  reading back.)
  */
 
+#ifdef HAVE_CONFIG_H
+#include "io_lib_config.h"
+#endif
 
 #include <stdio.h>
 #include <string.h> /* IMPORT: strdup (hopefully!) */
