@@ -12,22 +12,35 @@
 /*
  * Dumps a textual represenation of the hash table to stdout.
  */
-void HashTableLongDump(HashTable *h, FILE *fp, int long_format) {
+void HashTableLongDump(HashFile *hf, FILE *fp, int long_format) {
+    HashTable *h = hf->h;
     int i;
+
     for (i = 0; i < h->nbuckets; i++) {
 	HashItem *hi;
 	for (hi = h->bucket[i]; hi; hi = hi->next) {
 	    HashFileItem *hfi;
 	    hfi = (HashFileItem *)hi->data.p;
-	    if (long_format)
-		fprintf(fp, "%10"PRId64" %6"PRId32" %.*s\n",
-			hfi->pos, hfi->size, hi->key_len, hi->key);
+	    if (long_format) {
+		char *aname;
+		
+		if (hf->archives &&
+		    hfi->archive >= 0 &&
+		    hfi->archive < hf->narchives) {
+		    aname = hf->archives[hfi->archive];
+		} else {
+		    aname = "?";
+		}
+		fprintf(fp, "%10"PRId64" %6"PRId32" %.*s %s\n",
+			hfi->pos, hfi->size, hi->key_len, hi->key,
+			aname);
 		/*
 		fprintf(fp, "%10ld %6d %.*s\n",
 			hfi->pos, hfi->size, hi->key_len, hi->key);
 		*/
-	    else
+	    } else {
 		fprintf(fp, "%.*s\n", hi->key_len, hi->key);
+	    }
 	}
     }
 }
@@ -59,7 +72,7 @@ int main(int argc, char **argv) {
 
     hf = HashFileLoad(fp);
     if (hf) {
-	HashTableLongDump(hf->h, stdout, long_format);
+	HashTableLongDump(hf, stdout, long_format);
 	HashFileDestroy(hf);
     }
 
